==> cloudwatch-1.115.0-sources.jar: software/amazon/awscdk/services/cloudwatch/AlarmStatusWidgetProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for an Alarm Status Widget.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-07-21T15:55:57.887Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.AlarmStatusWidgetProps")
@software.amazon.jsii.Jsii.Proxy(AlarmStatusWidgetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AlarmStatusWidgetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * CloudWatch Alarms to show in widget.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> getAlarms();

    /**
     * Height of the widget.
     * <p>
     * Default: 3
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getHeight() {
        return null;
    }

    /**
     * The title of the widget.
     * <p>
     * Default: 'Alarm Status'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getTitle() {
        return null;
    }

    /**
     * Width of the widget, in a grid of 24 units wide.
     * <p>
     * Default: 6
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getWidth() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AlarmStatusWidgetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AlarmStatusWidgetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AlarmStatusWidgetProps> {
        private java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> alarms;
        private java.lang.Number height;
        private java.lang.String title;
        private java.lang.Number width;

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getAlarms}
         * @param alarms CloudWatch Alarms to show in widget. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder alarms(java.util.List<? extends software.amazon.awscdk.services.cloudwatch.IAlarm> alarms) {
            this.alarms = (java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm>)alarms;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getHeight}
         * @param height Height of the widget.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder height(java.lang.Number height) {
            this.height = height;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getTitle}
         * @param title The title of the widget.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder title(java.lang.String title) {
            this.title = title;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getWidth}
         * @param width Width of the widget, in a grid of 24 units wide.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder width(java.lang.Number width) {
            this.width = width;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AlarmStatusWidgetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AlarmStatusWidgetProps build() {
            return new Jsii$Proxy(alarms, height, title, width);
        }
    }

    /**
     * An implementation for {@link AlarmStatusWidgetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AlarmStatusWidgetProps {
        private final java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> alarms;
        private final java.lang.Number height;
        private final java.lang.String title;
        private final java.lang.Number width;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.alarms = software.amazon.jsii.Kernel.get(this, "alarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarm.class)));
            this.height = software.amazon.jsii.Kernel.get(this, "height", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.title = software.amazon.jsii.Kernel.get(this, "title", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.width = software.amazon.jsii.Kernel.get(this, "width", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final java.util.List<? extends software.amazon.awscdk.services.cloudwatch.IAlarm> alarms, final java.lang.Number height, final java.lang.String title, final java.lang.Number width) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.alarms = (java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm>)java.util.Objects.requireNonNull(alarms, "alarms is required");
            this.height = height;
            this.title = title;
            this.width = width;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> getAlarms() {
            return this.alarms;
        }

        @Override
        public final java.lang.Number getHeight() {
            return this.height;
        }

        @Override
        public final java.lang.String getTitle() {
            return this.title;
        }

        @Override
        public final java.lang.Number getWidth() {
            return this.width;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("alarms", om.valueToTree(this.getAlarms()));
            if (this.getHeight() != null) {
                data.set("height", om.valueToTree(this.getHeight()));
            }
            if (this.getTitle() != null) {
                data.set("title", om.valueToTree(this.getTitle()));
            }
            if (this.getWidth() != null) {
                data.set("width", om.valueToTree(this.getWidth()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.AlarmStatusWidgetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AlarmStatusWidgetProps.Jsii$Proxy that = (AlarmStatusWidgetProps.Jsii$Proxy) o;

            if (!alarms.equals(that.alarms)) return false;
            if (this.height != null ? !this.height.equals(that.height) : that.height != null) return false;
            if (this.title != null ? !this.title.equals(that.title) : that.title != null) return false;
            return this.width != null ? this.width.equals(that.width) : that.width == null;
        }

        @Override
        public final int hashCode() {
            int result = this.alarms.hashCode();
            result = 31 * result + (this.height != null ? this.height.hashCode() : 0);
            result = 31 * result + (this.title != null ? this.title.hashCode() : 0);
            result = 31 * result + (this.width != null ? this.width.hashCode() : 0);
            return result;
        }
    }
}

==> cloudwatch-1.173.0-sources.jar: software/amazon/awscdk/services/cloudwatch/AlarmStatusWidgetProps.java <==
package software.amazon.awscdk.services.cloudwatch;

/**
 * Properties for an Alarm Status Widget.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Dashboard dashboard;
 * Alarm errorAlarm;
 * dashboard.addWidgets(
 * AlarmStatusWidget.Builder.create()
 *         .alarms(List.of(errorAlarm))
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:27.163Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cloudwatch.$Module.class, fqn = "@aws-cdk/aws-cloudwatch.AlarmStatusWidgetProps")
@software.amazon.jsii.Jsii.Proxy(AlarmStatusWidgetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface AlarmStatusWidgetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * CloudWatch Alarms to show in widget.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> getAlarms();

    /**
     * Height of the widget.
     * <p>
     * Default: 3
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getHeight() {
        return null;
    }

    /**
     * Specifies how to sort the alarms in the widget.
     * <p>
     * Default: - alphabetical order
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cloudwatch.AlarmStatusWidgetSortBy getSortBy() {
        return null;
    }

    /**
     * Use this field to filter the list of alarms displayed in the widget to only those alarms currently in the specified states.
     * <p>
     * You can specify one or more alarm states in the value for this field.
     * The alarm states that you can specify are ALARM, INSUFFICIENT_DATA, and OK.
     * <p>
     * If you omit this field or specify an empty array, all the alarms specifed in alarms are displayed.
     * <p>
     * Default: -  all the alarms specified in alarms are displayed.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.cloudwatch.AlarmState> getStates() {
        return null;
    }

    /**
     * The title of the widget.
     * <p>
     * Default: 'Alarm Status'
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getTitle() {
        return null;
    }

    /**
     * Width of the widget, in a grid of 24 units wide.
     * <p>
     * Default: 6
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getWidth() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link AlarmStatusWidgetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link AlarmStatusWidgetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<AlarmStatusWidgetProps> {
        java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> alarms;
        java.lang.Number height;
        software.amazon.awscdk.services.cloudwatch.AlarmStatusWidgetSortBy sortBy;
        java.util.List<software.amazon.awscdk.services.cloudwatch.AlarmState> states;
        java.lang.String title;
        java.lang.Number width;

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getAlarms}
         * @param alarms CloudWatch Alarms to show in widget. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder alarms(java.util.List<? extends software.amazon.awscdk.services.cloudwatch.IAlarm> alarms) {
            this.alarms = (java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm>)alarms;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getHeight}
         * @param height Height of the widget.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder height(java.lang.Number height) {
            this.height = height;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getSortBy}
         * @param sortBy Specifies how to sort the alarms in the widget.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder sortBy(software.amazon.awscdk.services.cloudwatch.AlarmStatusWidgetSortBy sortBy) {
            this.sortBy = sortBy;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getStates}
         * @param states Use this field to filter the list of alarms displayed in the widget to only those alarms currently in the specified states.
         *               You can specify one or more alarm states in the value for this field.
         *               The alarm states that you can specify are ALARM, INSUFFICIENT_DATA, and OK.
         *               <p>
         *               If you omit this field or specify an empty array, all the alarms specifed in alarms are displayed.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder states(java.util.List<? extends software.amazon.awscdk.services.cloudwatch.AlarmState> states) {
            this.states = (java.util.List<software.amazon.awscdk.services.cloudwatch.AlarmState>)states;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getTitle}
         * @param title The title of the widget.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder title(java.lang.String title) {
            this.title = title;
            return this;
        }

        /**
         * Sets the value of {@link AlarmStatusWidgetProps#getWidth}
         * @param width Width of the widget, in a grid of 24 units wide.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder width(java.lang.Number width) {
            this.width = width;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link AlarmStatusWidgetProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public AlarmStatusWidgetProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link AlarmStatusWidgetProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements AlarmStatusWidgetProps {
        private final java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> alarms;
        private final java.lang.Number height;
        private final software.amazon.awscdk.services.cloudwatch.AlarmStatusWidgetSortBy sortBy;
        private final java.util.List<software.amazon.awscdk.services.cloudwatch.AlarmState> states;
        private final java.lang.String title;
        private final java.lang.Number width;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.alarms = software.amazon.jsii.Kernel.get(this, "alarms", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.IAlarm.class)));
            this.height = software.amazon.jsii.Kernel.get(this, "height", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.sortBy = software.amazon.jsii.Kernel.get(this, "sortBy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.AlarmStatusWidgetSortBy.class));
            this.states = software.amazon.jsii.Kernel.get(this, "states", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudwatch.AlarmState.class)));
            this.title = software.amazon.jsii.Kernel.get(this, "title", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.width = software.amazon.jsii.Kernel.get(this, "width", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.alarms = (java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm>)java.util.Objects.requireNonNull(builder.alarms, "alarms is required");
            this.height = builder.height;
            this.sortBy = builder.sortBy;
            this.states = (java.util.List<software.amazon.awscdk.services.cloudwatch.AlarmState>)builder.states;
            this.title = builder.title;
            this.width = builder.width;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.cloudwatch.IAlarm> getAlarms() {
            return this.alarms;
        }

        @Override
        public final java.lang.Number getHeight() {
            return this.height;
        }

        @Override
        public final software.amazon.awscdk.services.cloudwatch.AlarmStatusWidgetSortBy getSortBy() {
            return this.sortBy;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.cloudwatch.AlarmState> getStates() {
            return this.states;
        }

        @Override
        public final java.lang.String getTitle() {
            return this.title;
        }

        @Override
        public final java.lang.Number getWidth() {
            return this.width;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("alarms", om.valueToTree(this.getAlarms()));
            if (this.getHeight() != null) {
                data.set("height", om.valueToTree(this.getHeight()));
            }
            if (this.getSortBy() != null) {
                data.set("sortBy", om.valueToTree(this.getSortBy()));
            }
            if (this.getStates() != null) {
                data.set("states", om.valueToTree(this.getStates()));
            }
            if (this.getTitle() != null) {
                data.set("title", om.valueToTree(this.getTitle()));
            }
            if (this.getWidth() != null) {
                data.set("width", om.valueToTree(this.getWidth()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-cloudwatch.AlarmStatusWidgetProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            AlarmStatusWidgetProps.Jsii$Proxy that = (AlarmStatusWidgetProps.Jsii$Proxy) o;

            if (!alarms.equals(that.alarms)) return false;
            if (this.height != null ? !this.height.equals(that.height) : that.height != null) return false;
            if (this.sortBy != null ? !this.sortBy.equals(that.sortBy) : that.sortBy != null) return false;
            if (this.states != null ? !this.states.equals(that.states) : that.states != null) return false;
            if (this.title != null ? !this.title.equals(that.title) : that.title != null) return false;
            return this.width != null ? this.width.equals(that.width) : that.width == null;
        }

        @Override
        public final int hashCode() {
            int result = this.alarms.hashCode();
            result = 31 * result + (this.height != null ? this.height.hashCode() : 0);
            result = 31 * result + (this.sortBy != null ? this.sortBy.hashCode() : 0);
            result = 31 * result + (this.states != null ? this.states.hashCode() : 0);
            result = 31 * result + (this.title != null ? this.title.hashCode() : 0);
            result = 31 * result + (this.width != null ? this.width.hashCode() : 0);
            return result;
        }
    }
}
